@@ -1,8 +1,8 @@
-"""This script enables cancellation of all currently running skills on Misty."""
-from typing import Callable
+"""This module enables cancellation of all currently running skills."""
+from misty2py.robot import Misty
 
 
-def cancel_skills(misty: Callable):
+def cancel_skills(misty: Misty):
     """Cancels all skills currently running on Misty."""
     data = misty.get_info("skills_running")
     result = data.get("result", [])
