@@ -1,4 +1,4 @@
-"""This script enables the websocket information recieval from Misty.
+"""This module handles the communication of misty2py with Misty's WebSockets API and the communication between different threads created within misty2py for the WebSocket-related actions.
 """
 import json
 import threading
@@ -13,17 +13,16 @@ class MistyEvent:
     """A class that represents an event type subscribed to.
 
     Attributes:
-        server (str): Misty's websocket server address.
+        server (str): Misty's WebSockets API address.
         data (list): The data entries obtained.
-        type_str (str): The event type string as required by Misty's websockets.
+        type_str (str): The event type string as required by Misty's WebSockets API.
         event_name (str): A custom, unique event name.
-        return_property (str): The property to return as requeired by Misty's websockets.
+        return_property (str): The property to return as requeired by Misty's WebSockets API.
         debounce (int): The interval at which new information is sent in ms.
         log (list): The logs.
         len_data_entries (int): The maximum number of data entries to keep.
         ee (Union[bool, Callable]): The event emitter function if one is desired, False otherwise.
     """
-
     def __init__(
         self,
         ip: str,
@@ -38,14 +37,13 @@ class MistyEvent:
 
         Args:
             ip (str): Misty's IP address.
-            type_str (str): The event type string as required by Misty's websockets.
+            type_str (str): The event type string as required by Misty's WebSockets API.
             event_name (str): A custom, unique event name.
-            return_property (str): The property to return as required by Misty's websockets.
+            return_property (str): The property to return as required by Misty's WebSockets API.
             debounce (int): The interval at which new information is sent in ms.
             len_data_entries (int): The maximum number of data entries to keep.
             event_emitter (Union[Callable, None]): The event emitter function if one is desired, False otherwise.
         """
-
         self.server = "ws://%s/pubsub" % ip
         self.data = []
         self.type_str = type_str
@@ -61,6 +59,7 @@ class MistyEvent:
         else:
             self.ee = False
 
+
     def run(self):
         """Initialises the subscription and data collection."""
 
@@ -73,12 +72,13 @@ class MistyEvent:
         )
         self.ws.run_forever()
 
+
     def on_message(self, ws, message):
         """Saves received data and if ee is set, emits an event.
 
         Args:
-            ws (websocket.WebSocketApp): the event's websocket.
-            message (str): the data.
+            ws (websocket.WebSocketApp): The event's websocket.
+            message (str): The data received.
         """
 
         message = json.loads(message)
@@ -90,12 +90,13 @@ class MistyEvent:
         if self.ee:
             self.ee.emit(self.event_name, mes)
 
+
     def on_error(self, ws, error):
         """Logs an error and if ee is set, emits an 'error' event.
 
         Args:
-            ws (websocket.WebSocketApp): the event type's websocket.
-            error (str): the error message.
+            ws (websocket.WebSocketApp): The event type's websocket.
+            error (str): The error message received.
         """
 
         if len(self.log) > self.len_data_entries:
@@ -105,11 +106,12 @@ class MistyEvent:
         if self.ee:
             self.ee.emit("error_%s" % self.event_name, error)
 
+
     def on_close(self, ws):
         """Appends the closing message to the log and if ee is set, emits a 'close' event.
 
         Args:
-            ws (websocket.WebSocketApp): the event type's websocket.
+            ws (websocket.WebSocketApp): The event type's websocket.
         """
 
         mes = "Closed"
@@ -120,11 +122,12 @@ class MistyEvent:
         if self.ee:
             self.ee.emit("close_%s" % self.event_name, mes)
 
+
     def on_open(self, ws):
         """Appends the opening message to the log and starts the subscription and if ee is set, emits an 'open' event.
 
         Args:
-            ws (websocket.WebSocketApp): the event type's websocket.
+            ws (websocket.WebSocketApp): The event type's websocket.
         """
 
         self.log.append("Opened")
@@ -134,6 +137,7 @@ class MistyEvent:
         if self.ee:
             self.ee.emit("open_%s" % self.event_name)
 
+
     def subscribe(self):
         """Constructs the subscription message."""
 
@@ -147,10 +151,15 @@ class MistyEvent:
         msg_str = json.dumps(msg, separators=(",", ":"))
         self.ws.send(msg_str)
 
+
     def unsubscribe(self):
         """Constructs the unsubscription message."""
 
-        msg = {"Operation": "unsubscribe", "EventName": self.event_name, "Message": ""}
+        msg = {
+            "Operation": "unsubscribe",
+            "EventName": self.event_name,
+            "Message": ""
+        }
         msg_str = json.dumps(msg, separators=(",", ":"))
         self.ws.send(msg_str)
         self.ws.close()
@@ -160,33 +169,34 @@ class MistyEventHandler:
     """A class that handles all events its related Misty object subscribed to during this runtime.
 
     Attributes:
-        events (Dict): a dictionary of all Event objects its related Misty object subscribed to during this runtime.
-        ip (str): the IP address of the Misty belonging to this object's related Misty object.
+        events (Dict): The dictionary of all Event objects their related Misty object subscribed to during the current runtime.
+        ip (str): The IP address of the Misty belonging to this object's related Misty object.
     """
 
     def __init__(self, ip: str):
         """Initialises an object of class MistyEventHandler.
 
         Args:
-            ip (str): the IP address of the Misty belonging to this object's related Misty object.
+            ip (str): The IP address of the Misty belonging to this object's related Misty object.
         """
 
         self.events = {}
         self.ip = ip
 
+
     def subscribe_event(self, kwargs: Dict) -> Dict:
         """Subscribes to an event type.
 
         Args:
             kwargs (Dict):  requires a key "type" (a string representing the event type to subscribe to). Optional keys are:
-                - name (str) for a custom event name; must be unique.
-                - return_property (str) for the property to return from Misty's websockets; all properties are returned if return_property is not supplied.
-                - debounce (int) for the interval at which new information is sent in ms; defaults to 250.
-                - len_data_entries (int) for the maximum number of data entries to keep (discards in fifo style); defaults to 10.
-                - event_emitter (Callable) for an event emitter function which emits an event upon message recieval.
+            - `name` (str) for a custom event name; must be unique.
+            - `return_property` (str) for the property to return from Misty's websockets; all properties are returned if return_property is not supplied.
+            - `debounce` (int) for the interval at which new information is sent in ms; defaults to `250`.
+            - `len_data_entries` (int) for the maximum number of data entries to keep (discards in fifo style); defaults to `10`.
+            - `event_emitter` (Callable) for an event emitter function which emits an event upon message recieval.
 
         Returns:
-            Dict: success/fail message in the form of json dict.
+            Dict: Success/fail message in the form of a JSON dict.
         """
 
         event_type = kwargs.get("type")
@@ -220,11 +230,16 @@ class MistyEventHandler:
                 event_emitter,
             )
 
-        except:
+        except Exception as e:
             return {
                 "status": "Failed",
-                "message": "Unknown error occurred while attempting to subscribe to an event of type `%s`."
-                % event_type,
+                "message": "Error occurred while attempting \
+                    to subscribe to an event of type `%s`. \
+                        Error message: `%s`"
+                % (
+                    event_type,
+                    e
+                ),
             }
 
         self.events[event_name] = new_event
@@ -236,6 +251,7 @@ class MistyEventHandler:
             "event_name": event_name,
         }
 
+
     def get_event_data(self, kwargs: Dict) -> Dict:
         """Obtains data from a subscribed event type.
 
@@ -243,7 +259,7 @@ class MistyEventHandler:
             kwargs (Dict): Requires a key "name" (the event name).
 
         Returns:
-            Dict: the data or the fail message in the form of a json dict.
+            Dict: The data or the fail message in the form of a JSON dict.
         """
 
         event_name = kwargs.get("name")
@@ -252,24 +268,32 @@ class MistyEventHandler:
 
         if event_name in self.events.keys():
             try:
-                return {"status": "Success", "message": self.events[event_name].data}
-            except:
-                return {"status": "Failed", "message": "Unknown error occurred."}
+                return {
+                    "status": "Success",
+                    "message": self.events[event_name].data
+                }
+            except Exception as e:
+                return {
+                    "status": "Failed",
+                    "message": "Error occurred. Error message: `%s`" % e
+                }
 
         else:
             return {
                 "status": "Failed",
-                "message": "Event type `%s` is not subscribed to." % event_name,
+                "message": "Event type `%s` is not subscribed to."
+                % event_name,
             }
 
+
     def get_event_log(self, kwargs: Dict) -> Dict:
         """Obtains the log from a subscribed event type.
 
         Args:
-            kwargs (Dict): Requires a key "name" (the event name).
+            kwargs (Dict): Requires a key `name` (the event name).
 
         Returns:
-            Dict: the log or the fail message in the form of a json dict.
+            Dict: The log or the fail message in the form of a JSON dict.
         """
 
         event_name = kwargs.get("name")
@@ -278,12 +302,20 @@ class MistyEventHandler:
 
         if event_name in self.events.keys():
             try:
-                return {"status": "Success", "message": self.events[event_name].log}
-            except:
+                return {
+                    "status": "Success",
+                    "message": self.events[event_name].log
+                }
+            except Exception as e:
                 return {
                     "status": "Failed",
-                    "message": "Unknown error occurred while attempting to access the log of event `%s`."
-                    % event_name,
+                    "message": "Error occurred while attempting \
+                        to access the log of event `%s`. \
+                            Error message: `%s`"
+                    % (
+                        event_name,
+                        e
+                    ),
                 }
 
         else:
@@ -292,14 +324,15 @@ class MistyEventHandler:
                 "message": "Event `%s` is not subscribed to." % event_name,
             }
 
+
     def unsubscribe_event(self, kwargs: Dict) -> Dict:
         """Unsubscribes from an event type.
 
         Args:
-            kwargs (Dict): Requires a key "name" (the event name).
+            kwargs (Dict): Requires a key `name` (the event name).
 
         Returns:
-            Dict: success/fail message in the form of json dict.
+            Dict: Success/fail message in the form of JSON dict.
         """
 
         event_name = kwargs.get("name")
@@ -315,16 +348,22 @@ class MistyEventHandler:
                     % (event_name, self.events[event_name].type_str),
                     "log": self.events[event_name].log,
                 }
-            except:
+            except Exception as e:
                 mes = {
                     "status": "Failed",
-                    "message": "Unknown error occurred while attempting to unsubscribe from event `%s`."
-                    % event_name,
+                    "message": "Error occurred while attempting \
+                        to unsubscribe from event `%s`. \
+                            Error message: `%s`"
+                    % (
+                        event_name,
+                        e
+                    ),
                 }
             self.events.pop(event_name)
             return mes
         else:
             return {
                 "status": "Failed",
-                "message": "Event type `%s` is not subscribed to." % event_name,
+                "message": "Event type `%s` is not subscribed to."
+                % event_name,
             }
